@@ -1,14 +1,23 @@
 import os
 import json
+import logging
 from urllib.parse import urljoin
 from base64 import urlsafe_b64decode
 import requests
-from flask import request
 
 GCP_PROJECT = os.environ["GCP_PROJECT"]
 FUNCTION_REGION = os.environ["FUNCTION_REGION"]
 
 
+class ServiceError(Exception):
+    def __init__(self, status_code, message):
+        if status_code >= 500:
+            logging.error(message)
+        else:
+            logging.warning(message)
+        super().__init__(message)
+
+
 def _get_oidc_token(audience):
     if os.getenv("LOCAL"):
         from subprocess import Popen, PIPE
@@ -28,27 +37,20 @@ def _get_oidc_token(audience):
     ).content.decode()
 
 
-def call(name, data):
-    try:
-        domain = f"https://{FUNCTION_REGION}-{GCP_PROJECT}.cloudfunctions.net"
-        url = urljoin(domain, name)
-        headers = {"Authorization": "Bearer " + _get_oidc_token(url)}
-        r = requests.post(url, headers=headers, json=data)
-        return {
-            "success": r.status_code < 400,
-            "status_code": r.status_code,
-            "content": r.json(),
-        }
-    except Exception as e:
-        return {
-            "success": False,
-            "status_code": None,
-            "content": {"message": str(e)},
-        }
+def call(name, data=None):
+    domain = f"https://{FUNCTION_REGION}-{GCP_PROJECT}.cloudfunctions.net"
+    url = urljoin(domain, name)
+    headers = {"Authorization": "Bearer " + _get_oidc_token(url)}
+    logging.info("Service call: %s %s", name, data)
+    r = requests.post(url, headers=headers, json=data)
+    r.raise_for_status()
+    return r.json()
 
 
-def user_info():
-    encoded_user_info = request.headers.get("X-Endpoint-API-UserInfo")
+def user_info(request):
+    encoded_user_info = request.headers.get("X-Endpoint-Api-Userinfo")
     if encoded_user_info:
+        if not encoded_user_info.endswith("=="):
+            encoded_user_info += "=="
         return json.loads(urlsafe_b64decode(encoded_user_info))
     return None
